@@ -13,7 +13,7 @@ use Alien::m4;
 our @EXPORT_OK = qw(autoconf_dir automake_dir libtool_dir);
 
 # ABSTRACT: Build and install the GNU build system.
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 
 sub bin_dir
@@ -101,7 +101,7 @@ Alien::Autotools - Build and install the GNU build system.
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
@@ -176,6 +176,17 @@ Returns the directory path to automake
 
 Returns the directory path to libtool
 
+=head1 CAVEATS
+
+This module is typically needed for other L<Alien>s for a share install that use the
+autotools / GNU build system without bundling a pre-built C<configure> script.  If
+possible it is better to use a version of the alienized package that includes a
+pre-built C<configure> script.
+
+If you are a system vendor, then you should typically not need to package this module,
+check to see if the dependency that requires it can be built as a system install
+instead.
+
 =head1 SEE ALSO
 
 =over 4
@@ -204,7 +215,7 @@ Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Richard Simões.
+This software is Copyright (c) 2012-2022 by Richard Simões.
 
 This is free software, licensed under:
 
